@@ -123,6 +123,13 @@ class Mooi:
 			return -1
 		return 0
 
+	def is_test(self, line):
+		fname = line.split(":")[0]
+		test = self.DIR + os.sep + self.subdir + os.sep + fname
+		if not os.path.isfile(test):
+			return 0
+		return 1
+
 	# sort .lav data and combine with remaining untaken tests
 	def sort(self, lines):
 		scores = []
@@ -131,6 +138,7 @@ class Mooi:
 		lists = [scores, testables, tutors]
 		tests = []
 		for line in lines:
+			if not self.is_test(line): continue
 			if (string.find(line, '*SCORE*') != -1):
 				scores.append(line)
 			elif (string.find(line, '*TESTABLE*') != -1):
@@ -172,6 +180,7 @@ class Mooi:
 				if ((os.path.isdir(self.DIR + os.sep + file)) and
 					(file != 'py')):
 					dirs.append(file)
+			dirs.sort()		
 			self.subject = choice = self.query(dirs, 'Choose subject: ')
 			self.subdir = dirs[choice]
 		# set testing mode
